/* Main Simulation File */

#if defined(__cplusplus)
extern "C" {
#endif

#include "RoomHeating_OM_RH_model.h"
#include "simulation/solver/events.h"



/* dummy VARINFO and FILEINFO */
const VAR_INFO dummyVAR_INFO = omc_dummyVarInfo;

int RoomHeating_OM_RH_input_function(DATA *data, threadData_t *threadData)
{
  TRACE_PUSH

  (data->localData[0]->realVars[8] /* OAT variable */) = data->simulationInfo->inputVars[0];
  (data->localData[0]->realVars[10] /* fanspeed variable */) = data->simulationInfo->inputVars[1];
  (data->localData[0]->realVars[20] /* valveopen variable */) = data->simulationInfo->inputVars[2];
  
  TRACE_POP
  return 0;
}

int RoomHeating_OM_RH_input_function_init(DATA *data, threadData_t *threadData)
{
  TRACE_PUSH

  data->simulationInfo->inputVars[0] = data->modelData->realVarsData[8].attribute.start;
  data->simulationInfo->inputVars[1] = data->modelData->realVarsData[10].attribute.start;
  data->simulationInfo->inputVars[2] = data->modelData->realVarsData[20].attribute.start;
  
  TRACE_POP
  return 0;
}

int RoomHeating_OM_RH_input_function_updateStartValues(DATA *data, threadData_t *threadData)
{
  TRACE_PUSH

  data->modelData->realVarsData[8].attribute.start = data->simulationInfo->inputVars[0];
  data->modelData->realVarsData[10].attribute.start = data->simulationInfo->inputVars[1];
  data->modelData->realVarsData[20].attribute.start = data->simulationInfo->inputVars[2];
  
  TRACE_POP
  return 0;
}

int RoomHeating_OM_RH_inputNames(DATA *data, char ** names){
  TRACE_PUSH

  names[0] = (char *) data->modelData->realVarsData[8].info.name;
  names[1] = (char *) data->modelData->realVarsData[10].info.name;
  names[2] = (char *) data->modelData->realVarsData[20].info.name;
  
  TRACE_POP
  return 0;
}

int RoomHeating_OM_RH_data_function(DATA *data, threadData_t *threadData)
{
  TRACE_PUSH

  TRACE_POP
  return 0;
}

int RoomHeating_OM_RH_dataReconciliationInputNames(DATA *data, char ** names){
  TRACE_PUSH

  
  TRACE_POP
  return 0;
}

int RoomHeating_OM_RH_dataReconciliationUnmeasuredVariables(DATA *data, char ** names)
{
  TRACE_PUSH

  
  TRACE_POP
  return 0;
}

int RoomHeating_OM_RH_output_function(DATA *data, threadData_t *threadData)
{
  TRACE_PUSH

  data->simulationInfo->outputVars[0] = (data->localData[0]->realVars[9] /* RAT variable */);
  
  TRACE_POP
  return 0;
}

int RoomHeating_OM_RH_setc_function(DATA *data, threadData_t *threadData)
{
  TRACE_PUSH

  
  TRACE_POP
  return 0;
}

int RoomHeating_OM_RH_setb_function(DATA *data, threadData_t *threadData)
{
  TRACE_PUSH

  
  TRACE_POP
  return 0;
}


/*
equation index: 21
type: SIMPLE_ASSIGN
room.Qout = room.hAir * room.Awall * (room.RAT - wall.Tisurf)
*/
void RoomHeating_OM_RH_eqFunction_21(DATA *data, threadData_t *threadData)
{
  TRACE_PUSH
  const int equationIndexes[2] = {1,21};
  (data->localData[0]->realVars[14] /* room.Qout variable */) = ((data->simulationInfo->realParameter[6] /* room.hAir PARAM */)) * (((data->simulationInfo->realParameter[0] /* room.Awall PARAM */)) * ((data->localData[0]->realVars[0] /* room.RAT STATE(1) */) - (data->localData[0]->realVars[2] /* wall.Tisurf STATE(1) */)));
  TRACE_POP
}
/*
equation index: 22
type: SIMPLE_ASSIGN
room.fs = if fanspeed > 0.0 then fanspeed else 1e-4
*/
void RoomHeating_OM_RH_eqFunction_22(DATA *data, threadData_t *threadData)
{
  TRACE_PUSH
  const int equationIndexes[2] = {1,22};
  modelica_boolean tmp0;
  modelica_real tmp1;
  modelica_real tmp2;
  tmp1 = 1.0;
  tmp2 = 0.0;
  relationhysteresis(data, &tmp0, (data->localData[0]->realVars[10] /* fanspeed variable */), 0.0, tmp1, tmp2, 1, Greater, GreaterZC);
  (data->localData[0]->realVars[16] /* room.fs variable */) = (tmp0?(data->localData[0]->realVars[10] /* fanspeed variable */):1e-4);
  TRACE_POP
}
/*
equation index: 23
type: SIMPLE_ASSIGN
room.Qin = room.eps * room.mdotat * room.fs * room.cAir * (room.LWT - room.RAT)
*/
void RoomHeating_OM_RH_eqFunction_23(DATA *data, threadData_t *threadData)
{
  TRACE_PUSH
  const int equationIndexes[2] = {1,23};
  (data->localData[0]->realVars[13] /* room.Qin variable */) = ((data->simulationInfo->realParameter[5] /* room.eps PARAM */)) * (((data->simulationInfo->realParameter[7] /* room.mdotat PARAM */)) * (((data->localData[0]->realVars[16] /* room.fs variable */)) * (((data->simulationInfo->realParameter[3] /* room.cAir PARAM */)) * ((data->simulationInfo->realParameter[1] /* room.LWT PARAM */) - (data->localData[0]->realVars[0] /* room.RAT STATE(1) */)))));
  TRACE_POP
}
/*
equation index: 24
type: SIMPLE_ASSIGN
room.DT = room.Qin - room.Qout
*/
void RoomHeating_OM_RH_eqFunction_24(DATA *data, threadData_t *threadData)
{
  TRACE_PUSH
  const int equationIndexes[2] = {1,24};
  (data->localData[0]->realVars[11] /* room.DT variable */) = (data->localData[0]->realVars[13] /* room.Qin variable */) - (data->localData[0]->realVars[14] /* room.Qout variable */);
  TRACE_POP
}
/*
equation index: 25
type: SIMPLE_ASSIGN
$DER.room.RAT = room.DT / (room.vAir * room.cAir * room.rohAir)
*/
void RoomHeating_OM_RH_eqFunction_25(DATA *data, threadData_t *threadData)
{
  TRACE_PUSH
  const int equationIndexes[2] = {1,25};
  (data->localData[0]->realVars[4] /* der(room.RAT) STATE_DER */) = DIVISION_SIM((data->localData[0]->realVars[11] /* room.DT variable */),(((data->simulationInfo->realParameter[10] /* room.vAir PARAM */)) * ((data->simulationInfo->realParameter[3] /* room.cAir PARAM */))) * ((data->simulationInfo->realParameter[9] /* room.rohAir PARAM */)),"room.vAir * room.cAir * room.rohAir",equationIndexes);
  TRACE_POP
}
/*
equation index: 26
type: SIMPLE_ASSIGN
$DER.room.energy = room.Qin
*/
void RoomHeating_OM_RH_eqFunction_26(DATA *data, threadData_t *threadData)
{
  TRACE_PUSH
  const int equationIndexes[2] = {1,26};
  (data->localData[0]->realVars[5] /* der(room.energy) STATE_DER */) = (data->localData[0]->realVars[13] /* room.Qin variable */);
  TRACE_POP
}
/*
equation index: 27
type: SIMPLE_ASSIGN
room.mdota = room.fs * room.mdotat
*/
void RoomHeating_OM_RH_eqFunction_27(DATA *data, threadData_t *threadData)
{
  TRACE_PUSH
  const int equationIndexes[2] = {1,27};
  (data->localData[0]->realVars[17] /* room.mdota variable */) = ((data->localData[0]->realVars[16] /* room.fs variable */)) * ((data->simulationInfo->realParameter[7] /* room.mdotat PARAM */));
  TRACE_POP
}
/*
equation index: 28
type: SIMPLE_ASSIGN
room.SAT = (room.Qin - (-room.RAT) * room.cAir * room.mdota) / (room.mdota * room.cAir)
*/
void RoomHeating_OM_RH_eqFunction_28(DATA *data, threadData_t *threadData)
{
  TRACE_PUSH
  const int equationIndexes[2] = {1,28};
  (data->localData[0]->realVars[15] /* room.SAT variable */) = DIVISION_SIM((data->localData[0]->realVars[13] /* room.Qin variable */) - ((((-(data->localData[0]->realVars[0] /* room.RAT STATE(1) */))) * ((data->simulationInfo->realParameter[3] /* room.cAir PARAM */))) * ((data->localData[0]->realVars[17] /* room.mdota variable */))),((data->localData[0]->realVars[17] /* room.mdota variable */)) * ((data->simulationInfo->realParameter[3] /* room.cAir PARAM */)),"room.mdota * room.cAir",equationIndexes);
  TRACE_POP
}
/*
equation index: 29
type: SIMPLE_ASSIGN
room.vo = if valveopen > 0.0 then valveopen else 1e-4
*/
void RoomHeating_OM_RH_eqFunction_29(DATA *data, threadData_t *threadData)
{
  TRACE_PUSH
  const int equationIndexes[2] = {1,29};
  modelica_boolean tmp3;
  modelica_real tmp4;
  modelica_real tmp5;
  tmp4 = 1.0;
  tmp5 = 0.0;
  relationhysteresis(data, &tmp3, (data->localData[0]->realVars[20] /* valveopen variable */), 0.0, tmp4, tmp5, 0, Greater, GreaterZC);
  (data->localData[0]->realVars[19] /* room.vo variable */) = (tmp3?(data->localData[0]->realVars[20] /* valveopen variable */):1e-4);
  TRACE_POP
}
/*
equation index: 30
type: SIMPLE_ASSIGN
room.EWT = (room.LWT * room.cWater * room.mdotwt * room.vo - room.Qin) / (room.vo * room.mdotwt * room.cWater)
*/
void RoomHeating_OM_RH_eqFunction_30(DATA *data, threadData_t *threadData)
{
  TRACE_PUSH
  const int equationIndexes[2] = {1,30};
  (data->localData[0]->realVars[12] /* room.EWT variable */) = DIVISION_SIM(((((data->simulationInfo->realParameter[1] /* room.LWT PARAM */)) * ((data->simulationInfo->realParameter[4] /* room.cWater PARAM */))) * ((data->simulationInfo->realParameter[8] /* room.mdotwt PARAM */))) * ((data->localData[0]->realVars[19] /* room.vo variable */)) - (data->localData[0]->realVars[13] /* room.Qin variable */),(((data->localData[0]->realVars[19] /* room.vo variable */)) * ((data->simulationInfo->realParameter[8] /* room.mdotwt PARAM */))) * ((data->simulationInfo->realParameter[4] /* room.cWater PARAM */)),"room.vo * room.mdotwt * room.cWater",equationIndexes);
  TRACE_POP
}
/*
equation index: 31
type: SIMPLE_ASSIGN
room.mdotw = room.vo * room.mdotwt
*/
void RoomHeating_OM_RH_eqFunction_31(DATA *data, threadData_t *threadData)
{
  TRACE_PUSH
  const int equationIndexes[2] = {1,31};
  (data->localData[0]->realVars[18] /* room.mdotw variable */) = ((data->localData[0]->realVars[19] /* room.vo variable */)) * ((data->simulationInfo->realParameter[8] /* room.mdotwt PARAM */));
  TRACE_POP
}
/*
equation index: 32
type: SIMPLE_ASSIGN
$DER.wall.Tosurf = (wall.ho * wall.aWall * (OAT - wall.Tosurf) + (wall.Tisurf - wall.Tosurf) / wall.R) / wall.C
*/
void RoomHeating_OM_RH_eqFunction_32(DATA *data, threadData_t *threadData)
{
  TRACE_PUSH
  const int equationIndexes[2] = {1,32};
  (data->localData[0]->realVars[7] /* der(wall.Tosurf) STATE_DER */) = DIVISION_SIM(((data->simulationInfo->realParameter[16] /* wall.ho PARAM */)) * (((data->simulationInfo->realParameter[13] /* wall.aWall PARAM */)) * ((data->localData[0]->realVars[8] /* OAT variable */) - (data->localData[0]->realVars[3] /* wall.Tosurf STATE(1) */))) + DIVISION_SIM((data->localData[0]->realVars[2] /* wall.Tisurf STATE(1) */) - (data->localData[0]->realVars[3] /* wall.Tosurf STATE(1) */),(data->localData[0]->realVars[22] /* wall.R variable */),"wall.R",equationIndexes),(data->localData[0]->realVars[21] /* wall.C variable */),"wall.C",equationIndexes);
  TRACE_POP
}
/*
equation index: 33
type: SIMPLE_ASSIGN
$DER.wall.Tisurf = (wall.hi * wall.aWall * (room.RAT - wall.Tisurf) + (wall.Tosurf - wall.Tisurf) / wall.R) / wall.C
*/
void RoomHeating_OM_RH_eqFunction_33(DATA *data, threadData_t *threadData)
{
  TRACE_PUSH
  const int equationIndexes[2] = {1,33};
  (data->localData[0]->realVars[6] /* der(wall.Tisurf) STATE_DER */) = DIVISION_SIM(((data->simulationInfo->realParameter[15] /* wall.hi PARAM */)) * (((data->simulationInfo->realParameter[13] /* wall.aWall PARAM */)) * ((data->localData[0]->realVars[0] /* room.RAT STATE(1) */) - (data->localData[0]->realVars[2] /* wall.Tisurf STATE(1) */))) + DIVISION_SIM((data->localData[0]->realVars[3] /* wall.Tosurf STATE(1) */) - (data->localData[0]->realVars[2] /* wall.Tisurf STATE(1) */),(data->localData[0]->realVars[22] /* wall.R variable */),"wall.R",equationIndexes),(data->localData[0]->realVars[21] /* wall.C variable */),"wall.C",equationIndexes);
  TRACE_POP
}
/*
equation index: 34
type: SIMPLE_ASSIGN
RAT = room.RAT
*/
void RoomHeating_OM_RH_eqFunction_34(DATA *data, threadData_t *threadData)
{
  TRACE_PUSH
  const int equationIndexes[2] = {1,34};
  (data->localData[0]->realVars[9] /* RAT variable */) = (data->localData[0]->realVars[0] /* room.RAT STATE(1) */);
  TRACE_POP
}
/*
equation index: 36
type: ALGORITHM

  assert(room.EWT - room.LWT <= 5.0, "UTRC-FCU-001: Difference between EWT and LWT for HP should be less than 5 C");
*/
void RoomHeating_OM_RH_eqFunction_36(DATA *data, threadData_t *threadData)
{
  TRACE_PUSH
  const int equationIndexes[2] = {1,36};
  modelica_boolean tmp6;
  static const MMC_DEFSTRINGLIT(tmp7,75,"UTRC-FCU-001: Difference between EWT and LWT for HP should be less than 5 C");
  static int tmp8 = 0;
  if(!tmp8)
  {
    tmp6 = LessEq((data->localData[0]->realVars[12] /* room.EWT variable */) - (data->simulationInfo->realParameter[1] /* room.LWT PARAM */),5.0);
    if(!tmp6)
    {
      {
        const char* assert_cond = "(room.EWT - room.LWT <= 5.0)";
        if (data->simulationInfo->noThrowAsserts) {
          FILE_INFO info = {"/var/lib/jenkins1/ws/OpenModelica_PR-11632/testsuite/special/FmuExportCrossCompile/RoomHeating_OM.mo",70,5,70,130,0};
          infoStreamPrintWithEquationIndexes(LOG_ASSERT, info, 0, equationIndexes, "The following assertion has been violated %sat time %f\n(%s) --> \"%s\"", initial() ? "during initialization " : "", data->localData[0]->timeValue, assert_cond, MMC_STRINGDATA(MMC_REFSTRINGLIT(tmp7)));
        } else {
          FILE_INFO info = {"/var/lib/jenkins1/ws/OpenModelica_PR-11632/testsuite/special/FmuExportCrossCompile/RoomHeating_OM.mo",70,5,70,130,0};
          omc_assert_warning_withEquationIndexes(info, equationIndexes, "The following assertion has been violated %sat time %f\n(%s) --> \"%s\"", initial() ? "during initialization " : "", data->localData[0]->timeValue, assert_cond, MMC_STRINGDATA(MMC_REFSTRINGLIT(tmp7)));
        }
      }
      tmp8 = 1;
    }
  }
  TRACE_POP
}
/*
equation index: 35
type: ALGORITHM

  assert(fanspeed >= 0.01, "UTRC-FCU-002: FCU air damper should be opened at least 0.10.");
*/
void RoomHeating_OM_RH_eqFunction_35(DATA *data, threadData_t *threadData)
{
  TRACE_PUSH
  const int equationIndexes[2] = {1,35};
  modelica_boolean tmp9;
  static const MMC_DEFSTRINGLIT(tmp10,60,"UTRC-FCU-002: FCU air damper should be opened at least 0.10.");
  static int tmp11 = 0;
  if(!tmp11)
  {
    tmp9 = GreaterEq((data->localData[0]->realVars[10] /* fanspeed variable */),0.01);
    if(!tmp9)
    {
      {
        const char* assert_cond = "(fanspeed >= 0.01)";
        if (data->simulationInfo->noThrowAsserts) {
          FILE_INFO info = {"/var/lib/jenkins1/ws/OpenModelica_PR-11632/testsuite/special/FmuExportCrossCompile/RoomHeating_OM.mo",69,5,69,117,0};
          infoStreamPrintWithEquationIndexes(LOG_ASSERT, info, 0, equationIndexes, "The following assertion has been violated %sat time %f\n(%s) --> \"%s\"", initial() ? "during initialization " : "", data->localData[0]->timeValue, assert_cond, MMC_STRINGDATA(MMC_REFSTRINGLIT(tmp10)));
        } else {
          FILE_INFO info = {"/var/lib/jenkins1/ws/OpenModelica_PR-11632/testsuite/special/FmuExportCrossCompile/RoomHeating_OM.mo",69,5,69,117,0};
          omc_assert_warning_withEquationIndexes(info, equationIndexes, "The following assertion has been violated %sat time %f\n(%s) --> \"%s\"", initial() ? "during initialization " : "", data->localData[0]->timeValue, assert_cond, MMC_STRINGDATA(MMC_REFSTRINGLIT(tmp10)));
        }
      }
      tmp11 = 1;
    }
  }
  TRACE_POP
}

OMC_DISABLE_OPT
int RoomHeating_OM_RH_functionDAE(DATA *data, threadData_t *threadData)
{
  TRACE_PUSH
  int equationIndexes[1] = {0};
#if !defined(OMC_MINIMAL_RUNTIME)
  if (measure_time_flag) rt_tick(SIM_TIMER_DAE);
#endif

  data->simulationInfo->needToIterate = 0;
  data->simulationInfo->discreteCall = 1;
  RoomHeating_OM_RH_functionLocalKnownVars(data, threadData);
  RoomHeating_OM_RH_eqFunction_21(data, threadData);

  RoomHeating_OM_RH_eqFunction_22(data, threadData);

  RoomHeating_OM_RH_eqFunction_23(data, threadData);

  RoomHeating_OM_RH_eqFunction_24(data, threadData);

  RoomHeating_OM_RH_eqFunction_25(data, threadData);

  RoomHeating_OM_RH_eqFunction_26(data, threadData);

  RoomHeating_OM_RH_eqFunction_27(data, threadData);

  RoomHeating_OM_RH_eqFunction_28(data, threadData);

  RoomHeating_OM_RH_eqFunction_29(data, threadData);

  RoomHeating_OM_RH_eqFunction_30(data, threadData);

  RoomHeating_OM_RH_eqFunction_31(data, threadData);

  RoomHeating_OM_RH_eqFunction_32(data, threadData);

  RoomHeating_OM_RH_eqFunction_33(data, threadData);

  RoomHeating_OM_RH_eqFunction_34(data, threadData);

  RoomHeating_OM_RH_eqFunction_36(data, threadData);

  RoomHeating_OM_RH_eqFunction_35(data, threadData);
  data->simulationInfo->discreteCall = 0;
  
#if !defined(OMC_MINIMAL_RUNTIME)
  if (measure_time_flag) rt_accumulate(SIM_TIMER_DAE);
#endif
  TRACE_POP
  return 0;
}


int RoomHeating_OM_RH_functionLocalKnownVars(DATA *data, threadData_t *threadData)
{
  TRACE_PUSH

  
  TRACE_POP
  return 0;
}


/* forwarded equations */
extern void RoomHeating_OM_RH_eqFunction_21(DATA* data, threadData_t *threadData);
extern void RoomHeating_OM_RH_eqFunction_22(DATA* data, threadData_t *threadData);
extern void RoomHeating_OM_RH_eqFunction_23(DATA* data, threadData_t *threadData);
extern void RoomHeating_OM_RH_eqFunction_24(DATA* data, threadData_t *threadData);
extern void RoomHeating_OM_RH_eqFunction_25(DATA* data, threadData_t *threadData);
extern void RoomHeating_OM_RH_eqFunction_26(DATA* data, threadData_t *threadData);
extern void RoomHeating_OM_RH_eqFunction_32(DATA* data, threadData_t *threadData);
extern void RoomHeating_OM_RH_eqFunction_33(DATA* data, threadData_t *threadData);

static void functionODE_system0(DATA *data, threadData_t *threadData)
{
  {
    RoomHeating_OM_RH_eqFunction_21(data, threadData);
    threadData->lastEquationSolved = 21;
  }
  {
    RoomHeating_OM_RH_eqFunction_22(data, threadData);
    threadData->lastEquationSolved = 22;
  }
  {
    RoomHeating_OM_RH_eqFunction_23(data, threadData);
    threadData->lastEquationSolved = 23;
  }
  {
    RoomHeating_OM_RH_eqFunction_24(data, threadData);
    threadData->lastEquationSolved = 24;
  }
  {
    RoomHeating_OM_RH_eqFunction_25(data, threadData);
    threadData->lastEquationSolved = 25;
  }
  {
    RoomHeating_OM_RH_eqFunction_26(data, threadData);
    threadData->lastEquationSolved = 26;
  }
  {
    RoomHeating_OM_RH_eqFunction_32(data, threadData);
    threadData->lastEquationSolved = 32;
  }
  {
    RoomHeating_OM_RH_eqFunction_33(data, threadData);
    threadData->lastEquationSolved = 33;
  }
}

int RoomHeating_OM_RH_functionODE(DATA *data, threadData_t *threadData)
{
  TRACE_PUSH
#if !defined(OMC_MINIMAL_RUNTIME)
  if (measure_time_flag) rt_tick(SIM_TIMER_FUNCTION_ODE);
#endif

  
  data->simulationInfo->callStatistics.functionODE++;
  
  RoomHeating_OM_RH_functionLocalKnownVars(data, threadData);
  functionODE_system0(data, threadData);

#if !defined(OMC_MINIMAL_RUNTIME)
  if (measure_time_flag) rt_accumulate(SIM_TIMER_FUNCTION_ODE);
#endif

  TRACE_POP
  return 0;
}

/* forward the main in the simulation runtime */
extern int _main_SimulationRuntime(int argc, char**argv, DATA *data, threadData_t *threadData);

#include "RoomHeating_OM_RH_12jac.h"
#include "RoomHeating_OM_RH_13opt.h"

struct OpenModelicaGeneratedFunctionCallbacks RoomHeating_OM_RH_callback = {
   NULL,    /* performSimulation */
   NULL,    /* performQSSSimulation */
   NULL,    /* updateContinuousSystem */
   RoomHeating_OM_RH_callExternalObjectDestructors,    /* callExternalObjectDestructors */
   NULL,    /* initialNonLinearSystem */
   NULL,    /* initialLinearSystem */
   NULL,    /* initialMixedSystem */
   #if !defined(OMC_NO_STATESELECTION)
   RoomHeating_OM_RH_initializeStateSets,
   #else
   NULL,
   #endif    /* initializeStateSets */
   RoomHeating_OM_RH_initializeDAEmodeData,
   RoomHeating_OM_RH_functionODE,
   RoomHeating_OM_RH_functionAlgebraics,
   RoomHeating_OM_RH_functionDAE,
   RoomHeating_OM_RH_functionLocalKnownVars,
   RoomHeating_OM_RH_input_function,
   RoomHeating_OM_RH_input_function_init,
   RoomHeating_OM_RH_input_function_updateStartValues,
   RoomHeating_OM_RH_data_function,
   RoomHeating_OM_RH_output_function,
   RoomHeating_OM_RH_setc_function,
   RoomHeating_OM_RH_setb_function,
   RoomHeating_OM_RH_function_storeDelayed,
   RoomHeating_OM_RH_function_storeSpatialDistribution,
   RoomHeating_OM_RH_function_initSpatialDistribution,
   RoomHeating_OM_RH_updateBoundVariableAttributes,
   RoomHeating_OM_RH_functionInitialEquations,
   1, /* useHomotopy - 0: local homotopy (equidistant lambda), 1: global homotopy (equidistant lambda), 2: new global homotopy approach (adaptive lambda), 3: new local homotopy approach (adaptive lambda)*/
   NULL,
   RoomHeating_OM_RH_functionRemovedInitialEquations,
   RoomHeating_OM_RH_updateBoundParameters,
   RoomHeating_OM_RH_checkForAsserts,
   RoomHeating_OM_RH_function_ZeroCrossingsEquations,
   RoomHeating_OM_RH_function_ZeroCrossings,
   RoomHeating_OM_RH_function_updateRelations,
   RoomHeating_OM_RH_zeroCrossingDescription,
   RoomHeating_OM_RH_relationDescription,
   RoomHeating_OM_RH_function_initSample,
   RoomHeating_OM_RH_INDEX_JAC_A,
   RoomHeating_OM_RH_INDEX_JAC_B,
   RoomHeating_OM_RH_INDEX_JAC_C,
   RoomHeating_OM_RH_INDEX_JAC_D,
   RoomHeating_OM_RH_INDEX_JAC_F,
   RoomHeating_OM_RH_INDEX_JAC_H,
   RoomHeating_OM_RH_initialAnalyticJacobianA,
   RoomHeating_OM_RH_initialAnalyticJacobianB,
   RoomHeating_OM_RH_initialAnalyticJacobianC,
   RoomHeating_OM_RH_initialAnalyticJacobianD,
   RoomHeating_OM_RH_initialAnalyticJacobianF,
   RoomHeating_OM_RH_initialAnalyticJacobianH,
   RoomHeating_OM_RH_functionJacA_column,
   RoomHeating_OM_RH_functionJacB_column,
   RoomHeating_OM_RH_functionJacC_column,
   RoomHeating_OM_RH_functionJacD_column,
   RoomHeating_OM_RH_functionJacF_column,
   RoomHeating_OM_RH_functionJacH_column,
   RoomHeating_OM_RH_linear_model_frame,
   RoomHeating_OM_RH_linear_model_datarecovery_frame,
   RoomHeating_OM_RH_mayer,
   RoomHeating_OM_RH_lagrange,
   RoomHeating_OM_RH_pickUpBoundsForInputsInOptimization,
   RoomHeating_OM_RH_setInputData,
   RoomHeating_OM_RH_getTimeGrid,
   RoomHeating_OM_RH_symbolicInlineSystem,
   RoomHeating_OM_RH_function_initSynchronous,
   RoomHeating_OM_RH_function_updateSynchronous,
   RoomHeating_OM_RH_function_equationsSynchronous,
   RoomHeating_OM_RH_inputNames,
   RoomHeating_OM_RH_dataReconciliationInputNames,
   RoomHeating_OM_RH_dataReconciliationUnmeasuredVariables,
   RoomHeating_OM_RH_read_simulation_info,
   RoomHeating_OM_RH_read_input_fmu,
   NULL,
   NULL,
   -1,
   NULL,
   NULL,
   -1

};

#define _OMC_LIT_RESOURCE_0_name_data "BouncingBall"
#define _OMC_LIT_RESOURCE_0_dir_data "."
static const MMC_DEFSTRINGLIT(_OMC_LIT_RESOURCE_0_name,12,_OMC_LIT_RESOURCE_0_name_data);
static const MMC_DEFSTRINGLIT(_OMC_LIT_RESOURCE_0_dir,1,_OMC_LIT_RESOURCE_0_dir_data);

#define _OMC_LIT_RESOURCE_1_name_data "Complex"
#define _OMC_LIT_RESOURCE_1_dir_data "/var/lib/jenkins1/ws/OpenModelica_PR-11632/libraries/.openmodelica/libraries/Complex 4.0.0+maint.om"
static const MMC_DEFSTRINGLIT(_OMC_LIT_RESOURCE_1_name,7,_OMC_LIT_RESOURCE_1_name_data);
static const MMC_DEFSTRINGLIT(_OMC_LIT_RESOURCE_1_dir,99,_OMC_LIT_RESOURCE_1_dir_data);

#define _OMC_LIT_RESOURCE_2_name_data "FmuExportCrossCompile"
#define _OMC_LIT_RESOURCE_2_dir_data "."
static const MMC_DEFSTRINGLIT(_OMC_LIT_RESOURCE_2_name,21,_OMC_LIT_RESOURCE_2_name_data);
static const MMC_DEFSTRINGLIT(_OMC_LIT_RESOURCE_2_dir,1,_OMC_LIT_RESOURCE_2_dir_data);

#define _OMC_LIT_RESOURCE_3_name_data "Modelica"
#define _OMC_LIT_RESOURCE_3_dir_data "/var/lib/jenkins1/ws/OpenModelica_PR-11632/libraries/.openmodelica/libraries/Modelica 3.2.3+maint.om"
static const MMC_DEFSTRINGLIT(_OMC_LIT_RESOURCE_3_name,8,_OMC_LIT_RESOURCE_3_name_data);
static const MMC_DEFSTRINGLIT(_OMC_LIT_RESOURCE_3_dir,100,_OMC_LIT_RESOURCE_3_dir_data);

#define _OMC_LIT_RESOURCE_4_name_data "ModelicaServices"
#define _OMC_LIT_RESOURCE_4_dir_data "/var/lib/jenkins1/ws/OpenModelica_PR-11632/libraries/.openmodelica/libraries/ModelicaServices 4.0.0+maint.om"
static const MMC_DEFSTRINGLIT(_OMC_LIT_RESOURCE_4_name,16,_OMC_LIT_RESOURCE_4_name_data);
static const MMC_DEFSTRINGLIT(_OMC_LIT_RESOURCE_4_dir,108,_OMC_LIT_RESOURCE_4_dir_data);

#define _OMC_LIT_RESOURCE_5_name_data "RoomHeating_OM"
#define _OMC_LIT_RESOURCE_5_dir_data "/var/lib/jenkins1/ws/OpenModelica_PR-11632/testsuite/special/FmuExportCrossCompile"
static const MMC_DEFSTRINGLIT(_OMC_LIT_RESOURCE_5_name,14,_OMC_LIT_RESOURCE_5_name_data);
static const MMC_DEFSTRINGLIT(_OMC_LIT_RESOURCE_5_dir,82,_OMC_LIT_RESOURCE_5_dir_data);

#define _OMC_LIT_RESOURCE_6_name_data "WaterTank"
#define _OMC_LIT_RESOURCE_6_dir_data "/var/lib/jenkins1/ws/OpenModelica_PR-11632/testsuite/special/FmuExportCrossCompile"
static const MMC_DEFSTRINGLIT(_OMC_LIT_RESOURCE_6_name,9,_OMC_LIT_RESOURCE_6_name_data);
static const MMC_DEFSTRINGLIT(_OMC_LIT_RESOURCE_6_dir,82,_OMC_LIT_RESOURCE_6_dir_data);

static const MMC_DEFSTRUCTLIT(_OMC_LIT_RESOURCES,14,MMC_ARRAY_TAG) {MMC_REFSTRINGLIT(_OMC_LIT_RESOURCE_0_name), MMC_REFSTRINGLIT(_OMC_LIT_RESOURCE_0_dir), MMC_REFSTRINGLIT(_OMC_LIT_RESOURCE_1_name), MMC_REFSTRINGLIT(_OMC_LIT_RESOURCE_1_dir), MMC_REFSTRINGLIT(_OMC_LIT_RESOURCE_2_name), MMC_REFSTRINGLIT(_OMC_LIT_RESOURCE_2_dir), MMC_REFSTRINGLIT(_OMC_LIT_RESOURCE_3_name), MMC_REFSTRINGLIT(_OMC_LIT_RESOURCE_3_dir), MMC_REFSTRINGLIT(_OMC_LIT_RESOURCE_4_name), MMC_REFSTRINGLIT(_OMC_LIT_RESOURCE_4_dir), MMC_REFSTRINGLIT(_OMC_LIT_RESOURCE_5_name), MMC_REFSTRINGLIT(_OMC_LIT_RESOURCE_5_dir), MMC_REFSTRINGLIT(_OMC_LIT_RESOURCE_6_name), MMC_REFSTRINGLIT(_OMC_LIT_RESOURCE_6_dir)}};
void RoomHeating_OM_RH_setupDataStruc(DATA *data, threadData_t *threadData)
{
  assertStreamPrint(threadData,0!=data, "Error while initialize Data");
  threadData->localRoots[LOCAL_ROOT_SIMULATION_DATA] = data;
  data->callback = &RoomHeating_OM_RH_callback;
  OpenModelica_updateUriMapping(threadData, MMC_REFSTRUCTLIT(_OMC_LIT_RESOURCES));
  data->modelData->modelName = "RoomHeating_OM.RH";
  data->modelData->modelFilePrefix = "RoomHeating_OM_RH";
  data->modelData->resultFileName = NULL;
  data->modelData->modelDir = "/var/lib/jenkins1/ws/OpenModelica_PR-11632/testsuite/special/FmuExportCrossCompile";
  data->modelData->modelGUID = "{86d2915a-966f-4d5c-9cce-7444da3a2931}";
  data->modelData->initXMLData = NULL;
  data->modelData->modelDataXml.infoXMLData = NULL;
  GC_asprintf(&data->modelData->modelDataXml.fileName, "%s/RoomHeating_OM_RH_info.json", data->modelData->resourcesDir);
  data->modelData->runTestsuite = 0;
  data->modelData->nStates = 4;
  data->modelData->nVariablesReal = 23;
  data->modelData->nDiscreteReal = 0;
  data->modelData->nVariablesInteger = 0;
  data->modelData->nVariablesBoolean = 0;
  data->modelData->nVariablesString = 0;
  data->modelData->nParametersReal = 21;
  data->modelData->nParametersInteger = 0;
  data->modelData->nParametersBoolean = 0;
  data->modelData->nParametersString = 0;
  data->modelData->nInputVars = 3;
  data->modelData->nOutputVars = 1;
  data->modelData->nAliasReal = 6;
  data->modelData->nAliasInteger = 0;
  data->modelData->nAliasBoolean = 0;
  data->modelData->nAliasString = 0;
  data->modelData->nZeroCrossings = 2;
  data->modelData->nSamples = 0;
  data->modelData->nRelations = 2;
  data->modelData->nMathEvents = 0;
  data->modelData->nExtObjs = 0;
  data->modelData->modelDataXml.modelInfoXmlLength = 0;
  data->modelData->modelDataXml.nFunctions = 0;
  data->modelData->modelDataXml.nProfileBlocks = 0;
  data->modelData->modelDataXml.nEquations = 43;
  data->modelData->nMixedSystems = 0;
  data->modelData->nLinearSystems = 0;
  data->modelData->nNonLinearSystems = 0;
  data->modelData->nStateSets = 0;
  data->modelData->nJacobians = 6;
  data->modelData->nOptimizeConstraints = 0;
  data->modelData->nOptimizeFinalConstraints = 0;
  data->modelData->nDelayExpressions = 0;
  data->modelData->nBaseClocks = 0;
  data->modelData->nSpatialDistributions = 0;
  data->modelData->nSensitivityVars = 0;
  data->modelData->nSensitivityParamVars = 0;
  data->modelData->nSetcVars = 0;
  data->modelData->ndataReconVars = 0;
  data->modelData->nSetbVars = 0;
  data->modelData->nRelatedBoundaryConditions = 0;
  data->modelData->linearizationDumpLanguage = OMC_LINEARIZE_DUMP_LANGUAGE_MODELICA;
}

static int rml_execution_failed()
{
  fflush(NULL);
  fprintf(stderr, "Execution failed!\n");
  fflush(NULL);
  return 1;
}

